{-----------------------------------------------------------------------}
{                                                                       }
{           Subprogram Name:  amnani.dll                                }
{           Source Language:  Delphi                                    }
{           Author Name and Contact Information:                        }
{           Alexey M. Novosselov                                        }
{                                                                       }
{-----------------------------------------------------------------------}
{                                                                       }
{           Description:                                                }
{           amnani.dll interface unit                                   }
{                                                                       }
{-----------------------------------------------------------------------}

unit amnani_impl;

interface

uses
   Windows, Graphics;
   
   
   function _GetFrames(Handle: THandle; FileName: PChar): THandle;
   function _GetAniCursorInfo(Handle: THandle; FileName: PChar): Boolean;
   function _GetFramesRate(Handle: THandle; FileName: PChar): Integer;
   function _GetCursorCreator(Handle: THandle; FileName: PChar): ShortString;
   function _GetCursorTitle(Handle: THandle; FileName: PChar): ShortString;
   procedure _SaveFrameToFile(Handle: THandle; const FileName: PChar; const OutFileName: PChar; Index: Integer);
   procedure _SaveAllFramesToFile(Handle: THandle; const FileName: PChar; const OutFileNameTemplate: PChar);
   procedure _SaveAsBitmap(Handle: THandle; const FileName: PChar; const Bitmap: PChar; Background: TColor; Vertical: Boolean);
   
implementation

var
   GetFrames: function(FileName: PChar): THandle; stdcall;
   GetAniCursorInfo: function(Handle: THandle; FileName: PChar): Boolean; stdcall;
   GetFramesRate: function(FileName: PChar): Integer; stdcall;
   GetCursorCreator: function(Handle: THandle; FileName: PChar): ShortString; stdcall;
   GetCursorTitle: function(Handle: THandle; FileName: PChar): ShortString; stdcall;
   SaveFrameToFile: procedure(const FileName: PChar; const OutFileName: PChar; Index: Integer); stdcall;
   SaveAllFramesToFile: procedure(const FileName: PChar; const OutFileNameTemplate: PChar); stdcall;
   SaveAsBitmap: procedure(const FileName: PChar; const Bitmap: PChar;  Background: TColor; Vertical: Boolean); stdcall;


function _GetFrames(Handle: THandle; FileName: PChar): THandle;
var
   H: hInst;
begin
   {$T+}
   H := LoadLibrary(PChar('amnani.dll'));
   if H <= 0 then begin
      Result := 0;
      MessageBox(Handle, 'Cannot load amnani.dll', 'Load error', mb_ICONSTOP);
      Exit;
   end
   else
   begin
      @GetFrames := GetProcAddress(H, PChar('GetFrames'));
      if @GetFrames = nil
      then
      begin
         Result := 0;
         MessageBox(Handle, 'Function "GetFrames" not found in amnani.dll', 'Load error', mb_ICONSTOP);
         Exit;
      end
      else
         Result := GetFrames(FileName);
   end;
   FreeLibrary(H);
   {$T-}
end;

function _GetAniCursorInfo(Handle: THandle; FileName: PChar): Boolean;
var
   H: hInst;
begin
   H := LoadLibrary(PChar('amnani.dll'));
   if H <= 0 then begin
      MessageBox(Handle, 'Cannot load amnani.dll', 'Load error', mb_ICONSTOP);
      Result := False;
      Exit;
   end
   else
   begin
      @GetAniCursorInfo := GetProcAddress(H, PChar('GetAniCursorInfo'));
      if @GetAniCursorInfo = nil
      then
      begin
         MessageBox(Handle, 'Function "GetAniCursorInfo" not found in amnani.dll', 'Load error', mb_ICONSTOP);
         Result := False;
         Exit;
      end
      else
         Result := GetAniCursorInfo(Handle, FileName);
   end;
   FreeLibrary(H);
end;

function _GetFramesRate(Handle: THandle; FileName: PChar): Integer;
const
   cErrorFileNotFound = - 1;
   cError = - 2;
var
   H: hInst;
begin
   H := LoadLibrary(PChar('amnani.dll'));
   if H <= 0 then begin
      MessageBox(Handle, 'Cannot load amnani.dll', 'Load error', mb_ICONSTOP);
      Result := cErrorFileNotFound;
      Exit;
   end
   else
   begin
      @GetFramesRate := GetProcAddress(H, PChar('GetFramesRate'));
      if @GetFramesRate = nil
      then
      begin
         MessageBox(Handle, 'Function "GetFramesRate" not found in amnani.dll', 'Load error', mb_ICONSTOP);
         result := cError;
         Exit;
      end
      else
         Result := GetFramesRate( FileName);
   end;
   FreeLibrary(H);
end;

function _GetCursorCreator(Handle: THandle; FileName: PChar): ShortString;
var
   H: hInst;
begin
   H := LoadLibrary(PChar('amnani.dll'));
   if H <= 0 then begin
      MessageBox(Handle, 'Cannot load amnani.dll', 'Load error', mb_ICONSTOP);
      Result := '';
      Exit;
   end
   else
   begin
      @GetCursorCreator := GetProcAddress(H, PChar('GetCursorCreator'));
      if @GetCursorCreator = nil
      then
      begin
         MessageBox(Handle, 'Function "GetCursorCreator" not found in amnani.dll', 'Load error', mb_ICONSTOP);
         result := '';
         Exit;
      end
      else
         Result := GetCursorCreator(Handle, FileName);
   end;
   FreeLibrary(H);
end;

function _GetCursorTitle(Handle: THandle; FileName: PChar): ShortString;
var
   H: hInst;
begin
   H := LoadLibrary(PChar('amnani.dll'));
   if H <= 0 then begin
      MessageBox(Handle, 'Cannot load amnani.dll', 'Load error', mb_ICONSTOP);
      Result := '';
      Exit;
   end
   else
   begin
      @GetCursorTitle := GetProcAddress(H, PChar('GetCursorTitle'));
      if @GetCursorTitle = nil
      then
      begin
         MessageBox(Handle, 'Function "GetCursorTitle" not found in amnani.dll', 'Load error', mb_ICONSTOP);
         result := '';
         Exit;
      end
      else
         Result := GetCursorTitle(Handle, FileName);
   end;
   FreeLibrary(H);
end;

procedure _SaveAllFramesToFile(Handle: THandle; const FileName: PChar; const OutFileNameTemplate: PChar);
var
   H: hInst;
begin
   H := LoadLibrary(PChar('amnani.dll'));
   if H <= 0 then begin
      MessageBox(Handle, 'Cannot load amnani.dll', 'Load error', mb_ICONSTOP);
      Exit;
   end
   else
   begin
      @SaveAllFramesToFile := GetProcAddress(H, PChar('SaveAllFramesToFile'));
      if @SaveAllFramesToFile = nil
      then
      begin
         MessageBox(Handle, 'Function "SaveAllFramesToFile" not found in amnani.dll', 'Load error', mb_ICONSTOP);
         Exit;
      end
      else
         SaveAllFramesToFile(FileName, OutFileNameTemplate);
   end;
   FreeLibrary(H);
end;

procedure _SaveAsBitmap(Handle: THandle; const FileName: PChar; const Bitmap: PChar; Background: TColor; Vertical: Boolean);
var
   H: hInst;
begin
   H := LoadLibrary(PChar('amnani.dll'));
   if H <= 0 then begin
      MessageBox(Handle, 'Cannot load amnani.dll', 'Load error', mb_ICONSTOP);
      Exit;
   end
   else
   begin
      @SaveAsBitmap := GetProcAddress(H, PChar('SaveAsBitmap'));
      if @SaveAsBitmap = nil
      then
      begin
         MessageBox(Handle, 'Function "SaveAsBitmap" not found in amnani.dll', 'Load error', mb_ICONSTOP);
         Exit;
      end
      else
         SaveAsBitmap(FileName, Bitmap, Background, Vertical);
   end;
   FreeLibrary(H);
end;

procedure _SaveFrameToFile(Handle: THandle; const FileName: PChar; const OutFileName: PChar; Index: Integer);
var
   H: hInst;
begin
   H := LoadLibrary(PChar('amnani.dll'));
   if H <= 0 then begin
      MessageBox(Handle, 'Cannot load amnani.dll', 'Load error', mb_ICONSTOP);
      Exit;
   end
   else
   begin
      @SaveFrameToFile := GetProcAddress(H, PChar('SaveFrameToFile'));
      if @SaveFrameToFile = nil
      then
      begin
         MessageBox(Handle, 'Function "SaveFrameToFile" not found in amnani.dll', 'Load error', mb_ICONSTOP);
         Exit;
      end
      else
         SaveFrameToFile(FileName, OutFileName, Index);
   end;
   FreeLibrary(H);
end;

end.

